# Audit: ADR-0.15.0-pydantic-schema-enforcement

- ADR: `docs\design\adr\pre-release\ADR-0.15.0-pydantic-schema-enforcement\ADR-0.15.0-pydantic-schema-enforcement.md`

## Results
- **test**: PASS (`uv run gz test`) -> `docs\design\adr\pre-release\ADR-0.15.0-pydantic-schema-enforcement\audit\proofs\test.txt`
- **lint**: PASS (`uv run gz lint`) -> `docs\design\adr\pre-release\ADR-0.15.0-pydantic-schema-enforcement\audit\proofs\lint.txt`
- **typecheck**: PASS (`uv run gz typecheck`) -> `docs\design\adr\pre-release\ADR-0.15.0-pydantic-schema-enforcement\audit\proofs\typecheck.txt`
- **docs**: PASS (`uv run mkdocs build --strict`) -> `docs\design\adr\pre-release\ADR-0.15.0-pydantic-schema-enforcement\audit\proofs\docs.txt`
